#!/bin/bash

# INIT EDITABLE SECTION ####################################

# LANGUAGES
L="es ca en"
DOMAIN=syncer_plank_gui

# SOURCE FILES
GLADEFILE=gui_v3.glade
GUIFILE=syncer-plank-gui

# I18N TOOLS
INTLTOOL=intltool-extract
XGETTEXT=xgettext
MSGINIT=msginit
MSGFMT=msgfmt
VIRTAAL=virtaal

# PATHS
OUTDIR=./tmp_locales_generated

# END EDITABLE SECTION #####################################

function check_util(){
    if [ -z "$(which $1)" ]; then 
        echo Need $1
        exit 1
    else
        echo $1 Found ! OK !
    fi
}
function check_file(){
    if [ ! -f "$1" ]; then 
        echo Need $1
        exit 1
    else
        echo $1 Found ! OK !
    fi
}

function check_dir(){
    if [ ! -d "$1" ]; then 
        echo Need $1
        exit 1
    else
        echo $1 Found ! OK !
    fi
}

THIS_SCRIPT="$(readlink -f "$0")"
EXECUTION_DIR="$(dirname $THIS_SCRIPT)"
GLADEFILE_PATH=$EXECUTION_DIR/../../lib/syncer-plank/$GLADEFILE
GUIFILE_PATH=$EXECUTION_DIR/../../bin/$GUIFILE

check_util $INTLTOOL
check_util $XGETTEXT
check_util $MSGINIT
check_util $MSGFMT
check_util $VIRTAAL
check_file $GLADEFILE_PATH
check_file $GUIFILE_PATH

# MAIN SCRIPT
if [ $# -lt 1 -o $# -gt 1 ];then
        echo "$0 Need parameter!"
	echo "$0 init"
	echo "$0 translate"
	echo "$0 generate"
	echo "$0 copy"
	exit 1
fi
if [ ! -d "$OUTDIR" ]; then 
    mkdir -p $OUTDIR
fi
if [ "x$1" = "xinit" ]; then
        mkdir -p ./tmp
        cp $GLADEFILE_PATH ./tmp/$GLADEFILE
        cp $GUIFILE_PATH ./tmp/$GUIFILE
	$INTLTOOL -l --type=gettext/glade ./tmp/$GLADEFILE
	$XGETTEXT --language=Python --keyword=_ --keyword=N_ --output=$OUTDIR/$DOMAIN.pot ./tmp/$GUIFILE ./tmp/$GLADEFILE.h
	mv ./tmp/* $OUTDIR
	rmdir ./tmp
fi

for l in $L; do
	if [ "x$1" = "xinit" ]; then
		mkdir -p $OUTDIR/$l/LC_MESSAGES/
		$MSGINIT --no-translator --locale=$l --input=$OUTDIR/$DOMAIN.pot -o $OUTDIR/$l/LC_MESSAGES/$l.po
	fi
	if [ "x$1" = "xtranslate" ]; then
	        check_file $OUTDIR/$l/LC_MESSAGES/$l.po
		$VIRTAAL $OUTDIR/$l/LC_MESSAGES/$l.po
	fi
	if [ "x$1" = "xgenerate" ]; then
	        check_file $OUTDIR/$l/LC_MESSAGES/$l.po
		$MSGFMT $OUTDIR/$l/LC_MESSAGES/$l.po -o $OUTDIR/$l/LC_MESSAGES/$DOMAIN.mo
	fi
	if [ "x$1" = "xcopy" ]; then
	        check_file $OUTDIR/$l/LC_MESSAGES/$DOMAIN.mo
	        if [ "$l" = "es" ]; then
	            d="es es_ES es_ES.UTF-8"
	        fi
	        if [ "$l" = "ca" ]; then
	            d="ca ca_ES@valencia ca_ES.UTF-8@valencia"
	        fi
	        if [ "$l" = "en" ]; then
	            d="en"
	        fi
	        cp $OUTDIR/$l/LC_MESSAGES/$l.po $EXECUTION_DIR/
	        for l2 in $d; do
	            check_dir $EXECUTION_DIR/../locale/$l2/LC_MESSAGES
	            echo copy $DOMAIN.mo into $EXECUTION_DIR/../locale/$l2/LC_MESSAGES/
	            cp $OUTDIR/$l/LC_MESSAGES/$DOMAIN.mo $EXECUTION_DIR/../locale/$l2/LC_MESSAGES/$DOMAIN.mo
		done
	fi
done
exit 0
